pub struct ClientTlsRuntimeConfig {
pub components: Vec<String>,
pub hosts: Vec<String>,
pub use_platform_roots: bool,
pub use_webpki_roots: bool,
pub root_certificates: Vec<CertificateDer<'static>>,
pub client_cert: Option<ClientCertRuntimeConfig>,
}Expand description
TLS configuration for one or more component(s) and host(s).
Fields
components: Vec<String>The component(s) this configuration applies to.
hosts: Vec<String>The host(s) this configuration applies to.
use_platform_roots: boolIf true, the operating system’s certificate store will be used for
root certificate verification
rustls-platform-verifier.
By default this is true.
use_webpki_roots: boolIf true, the “standard” CA certs in the
webpki-root-certs crate will be considered valid
roots.
By default this is true.
root_certificates: Vec<CertificateDer<'static>>A set of CA certs that should be considered valid roots.
These will be used in addition to roots enabled by
use_platform_roots and
use_webpki_roots.
client_cert: Option<ClientCertRuntimeConfig>A certificate and private key to be used as the client certificate for “mutual TLS” (mTLS).